bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 1. Aventiure
___________________________________________________ #### Auenture von den Nibelungen
| ### UNS IST> In alten mæren wnders vil geseit ### von heleden lobebæren von grozer arebeit ### von frevde vn– hochgeciten von weinen vn– klagen ### von kvner recken striten mvget ir nv wnder horen sagen ### Ez whs <inBvregonden> ein vil edel magedin ### daz in allen landen niht schoners mohte sin ### Chriemhilt geheizen div wart ein schone wip ### dar vmbe mvsin degene vil verliesen den lip ### Ir pflagen dri kunige edel un– rich ### Gunther un– Gernot die rechen lobelich ### vn– Giselher der iunge ein wetlicher degen ### div frowe was ir swester die helde hetens inir pflegen
###### 4 | ### Ein richiv chuniginne frov Vte ir mvter hiez ### ir vater der hiez Dancrât der in div erbe liez ### sit nach sime lebene ein ellens richer man ### der ovch insiner iugende grozer eren vil gewan
###### 5 | ### Die herren waren milte von arde hoh erborn ### mit kraft vn– mazen chvne die rechen vz erchorn ### da zen Bvrgonden so was ir lant genant ### si frvmten starchiv wnder sit in Etzelen lant
###### 6 | ### Ze Wormze bi dem Rine si wonten mit ir chraft ### in dienten von ir landen vil stolziv ritterschaft ### mit lobelichen eren vnz an ir endes zit ### si sturben iæmerliche sit von zweier frowen nit
| ### Die dri kunige waren als ich gesaget <han> ### von vil hohem ellen in waren vndertan ### ovch die besten rechen von den man hat gesaget ### starch vn– vil chvone inscharpfen striten vnverzaget
###### 8 | ### Daz was von tronege hagene vn– ovoch der bruder sin ### Danchwart der snelle von Metzzen Ortwin ### die zwene marcgrauen Gere vn– Ekkewart ### Volker von Alzeye mit ganzem ellen wol be wart
###### 9 | ### Rvomolt der chvchen meister ein vz erwelter degen ### Sindolt vn– Hvnolt dise herren mvsin pflegen ### des hoves vn– der eren der drier kunige man ### si heten noch manigen rechen des ich genennen nienen kan
###### 10 | ### Danchwart der was marschalch do was der nefe sin ### trvhsetze des kuniges von Mezzen Ortwin ### Sindolt der was schenche ein wetlicher degen ### Hvnolt was chame[1v]rære si chunden hoher eren pflegen
###### 11 | ### Von des hofes ere vn– von ir witen chraft ### von ir vil hohen werdekeit vn– von ir ritterschaft ### der die herren pflagen mit frevden al ir leben ### des enchunde iv ze ware niemen gar ein ende geben
| ### INDisen hohen eren trvmte Chriemilde ### wie si zvge einen valchen starch schon vn– wilde ### den ir zwene arn erchrvmmen daz si daz mvste sehen ### ir enkunde indirre werlde leider nimmer <geschehen>
###### 13 | ### Den trvom si do sagete ir <mvoter> voten ### sine chundes niht beschaiden baz der gvten ### der valche den dv zivhest daz ist ein edel man ### in welle got behvten dv mvst in schier vloren han
###### 14 | ### Waz saget ir mir von manne vil liebiv mvter min ### ane <rechen> minne so wil ich immer sin ### svs schon ich wil beliben vnz an minen tot ### daz ich von rechen minne sol gewinnen nimmer not
###### 15 | ### Nvne versprich ez niht zesere sprach ir mvter do ### soltv immer hercenliche zer werlde werden vro ### daz chvmt von mannes minne dv wirst ein schone wip ### ob dir got gefuget eins rehte gvten ritters lip
###### 16 | ### Die rede lat beliben vil liebiv frowe min ### ez ist an manigen wiben vil diche worden schin ### wie liebe mit leide zeiungest lonen chan ### ich sol si miden beide sone chan mir nimmer missegan
| ### Chriemhilt in ir mvte sich minne gar bewach ### sit lebete div uil gvte vil manigen lieben tac ### daz sine wesse niemen den minnen wolde ir lip ### sit wart si mit eren eines vil werden rechen wip
###### 18 | ### Der was der selbe valche den si in ir trvome sach ### den ir beschiet ir mvoter wie sere si daz rach ### an ir nehsten magen die in slvgen sint ### durch sin eines sterben starp vil manich mvoter kint

<<< Übersicht <<< vorige Seite nächste Seite >>>